<?php

add_action('admin_init', 'medo_opengraph_admin_init_action');
add_action('admin_menu', 'medo_opengraph_admin_menu_action');


function medo_opengraph_admin_init_action() {
    register_setting('medo_opengraph_settings_group',
                     'medo_opengraph_site_facebook_admin_id',
                     'medo_opengraph_settings_sanitize_facebook_id_callback'
    );
    register_setting('medo_opengraph_settings_group',
                     'medo_opengraph_site_twitter_name',
                     'medo_opengraph_settings_sanitize_twitter_name_callback'
    );
    register_setting('medo_opengraph_settings_group',
                     'medo_opengraph_fallback_facebook_id',
                     'medo_opengraph_settings_sanitize_facebook_id_callback'
    );
    register_setting('medo_opengraph_settings_group',
                     'medo_opengraph_fallback_twitter_name',
                     'medo_opengraph_settings_sanitize_twitter_name_callback'
    );


    add_settings_section('medo_opengraph_settings_site_section',
                         'Site Settings',
                         'medo_opengraph_settings_site_section_callback',
                         'medo_opengraph_settings_page'
    );
    add_settings_field('medo_opengraph_site_facebook_admin_id',
                       'Facebook Admin ID',
                       'medo_opengraph_settings_site_facebook_admin_id_callback',
                       'medo_opengraph_settings_page',
                       'medo_opengraph_settings_site_section'
    );
    add_settings_field('medo_opengraph_site_twitter_name',
                       'Twitter Name',
                       'medo_opengraph_settings_site_twitter_name_callback',
                       'medo_opengraph_settings_page',
                       'medo_opengraph_settings_site_section'
    );

    add_settings_section('medo_opengraph_settings_fallback_section',
                         'Site Settings',
                         'medo_opengraph_settings_fallback_section_callback',
                         'medo_opengraph_settings_page'
    );
    add_settings_field('medo_opengraph_fallback_facebook_id',
                       'Facebook ID',
                       'medo_opengraph_settings_fallback_facebook_id_callback',
                       'medo_opengraph_settings_page',
                       'medo_opengraph_settings_fallback_section'
    );
    add_settings_field('medo_opengraph_fallback_twitter_name',
                       'Twitter Name',
                       'medo_opengraph_settings_fallback_twitter_name_callback',
                       'medo_opengraph_settings_page',
                       'medo_opengraph_settings_fallback_section'
    );
}


function medo_opengraph_admin_menu_action() {
    add_options_page('Medo OpenGraph Settings',
                     'Medo OpenGraph',
                     'manage_options',
                     'medo_opengraph_settings_page',
                     'medo_opengraph_settings_callback'
    );
}


function medo_opengraph_settings_callback() {
    $facebook_admin_id = get_option('medo_opengraph_facebook_admin_id');
    ?>
        <div class="wrap">
            <h2>Medo OpenGraph</h2>

            <form method="post" action="options.php">
                <?php settings_fields('medo_opengraph_settings_group'); ?>

                <?php medo_opengraph_settings_site_section_callback(); ?>
                <table class="form-table">
                    <tr>
                        <th><label for="medo_opengraph_site_facebook_admin_id">Facebook Admin ID</label></th>
                        <td><?php medo_opengraph_settings_site_facebook_admin_id_callback(); ?></td>
                    </tr>
                    <tr>
                        <th><label for="medo_opengraph_site_twitter_name">Twitter name</label></th>
                        <td><?php medo_opengraph_settings_site_twitter_name_callback(); ?></td>
                    </tr>
                </table>

                <?php medo_opengraph_settings_fallback_section_callback(); ?>
                <table class="form-table">
                    <tr>
                        <th><label for="medo_opengraph_fallback_facebook_id">Facebook ID</label></th>
                        <td><?php medo_opengraph_settings_fallback_facebook_id_callback(); ?></td>
                    </tr>
                    <tr>
                        <th><label for="medo_opengraph_fallback_twitter_name">Twitter name</label></th>
                        <td><?php medo_opengraph_settings_fallback_twitter_name_callback(); ?></td>
                    </tr>
                </table>

                <p class="submit">
                    <input type="submit" class="button-primary" value="<?php _e('Save Changes') ?>" />
                </p>
            </form>
        </div>
    <?php
}


function medo_opengraph_settings_site_section_callback() { ?> <h3>Site Settings</h3> <?php }

function medo_opengraph_settings_site_facebook_admin_id_callback() {
    $facebook_admin_id = get_option('medo_opengraph_site_facebook_admin_id');
    ?>
        <input type="text" name="medo_opengraph_site_facebook_admin_id" value="<?php echo $facebook_admin_id; ?>" placeholder="none" />
        <span class="description">Facebook Admin ID to be used on every page.</span>
    <?php
}

function medo_opengraph_settings_site_twitter_name_callback() {
    $twitter_name = get_option('medo_opengraph_site_twitter_name');
    ?>
        <input type="text" name="medo_opengraph_site_twitter_name" value="<?php echo $twitter_name; ?>" placeholder="none" />
        <span class="description">Twitter name to be used on every page.</span>
    <?php
}


function medo_opengraph_settings_fallback_section_callback() { ?> <h3>Fallback Settings</h3> <?php }

function medo_opengraph_settings_fallback_facebook_id_callback() {
    $facebook_id = get_option('medo_opengraph_fallback_facebook_id');
    ?>
        <input type="text" name="medo_opengraph_fallback_facebook_id" value="<?php echo $facebook_id; ?>" placeholder="none" />
        <span class="description">Facebook ID to be used for post where author hasn't got one defined.</span>
    <?php
}

function medo_opengraph_settings_fallback_twitter_name_callback() {
    $twitter_name = get_option('medo_opengraph_fallback_twitter_name');
    ?>
        <input type="text" name="medo_opengraph_fallback_twitter_name" value="<?php echo $twitter_name; ?>" placeholder="none" />
        <span class="description">Twitter name to be used for post where author hasn't got one defined.</span>
    <?php
}



function medo_opengraph_settings_sanitize_facebook_id_callback($input) {
    $input = trim($input);
    if (preg_match('/^[0-9]{0,15}$/', $input)) { return $input; }
}

function medo_opengraph_settings_sanitize_twitter_name_callback($input) {
    $input = trim($input);
    if (preg_match('/^[a-z0-9_]{0,15}$/', $input)) { return $input; }
}

?>
